@@ -52,7 +52,10 @@ from tdw.FBOutput import StaticOculusTouch as StatOc
 from tdw.FBOutput import StaticCompositeObjects as StatComp
 from tdw.FBOutput import DynamicCompositeObjects as DynComp
 from tdw.FBOutput import AudioSourceDone as AudDone
+from tdw.FBOutput import ObiParticles as ObiP
 from tdw.vr_data.oculus_touch_button import OculusTouchButton
+from tdw.FBOutput import ObjectColliderIntersection as ObjColInt
+from tdw.FBOutput import EnvironmentColliderIntersection as EnvColInt
 import numpy as np
 from typing import Tuple, Optional, List
 
@@ -1258,6 +1261,37 @@ class EmptyObjects(OutputData):
         return self._positions[index]
 
 
+class ObjectColliderIntersection(OutputData):
+    def get_data(self) -> ObjColInt.ObjectColliderIntersection:
+        return ObjColInt.ObjectColliderIntersection.GetRootAsObjectColliderIntersection(self.bytes, 0)
+
+    def get_object_id_a(self) -> int:
+        return self.data.ObjectIdA()
+
+    def get_object_id_b(self) -> int:
+        return self.data.ObjectIdB()
+
+    def get_distance(self) -> float:
+        return self.data.Distance()
+
+    def get_direction(self) -> Tuple[float, float, float]:
+        return OutputData._get_xyz(self.data.Direction())
+
+
+class EnvironmentColliderIntersection(OutputData):
+    def get_data(self) -> EnvColInt.EnvironmentColliderIntersection:
+        return EnvColInt.EnvironmentColliderIntersection.GetRootAsEnvironmentColliderIntersection(self.bytes, 0)
+
+    def get_object_id(self) -> int:
+        return self.data.ObjectId()
+
+    def get_distance(self) -> float:
+        return self.data.Distance()
+
+    def get_direction(self) -> Tuple[float, float, float]:
+        return OutputData._get_xyz(self.data.Direction())
+
+
 class StaticCompositeObjects(OutputData):
     def get_data(self) -> StatComp.StaticCompositeObjects:
         return StatComp.StaticCompositeObjects.GetRootAsStaticCompositeObjects(self.bytes, 0)
@@ -1386,3 +1420,32 @@ class DynamicCompositeObjects(OutputData):
 
     def get_light_is_on(self, index: int, light_index: int) -> bool:
         return self.data.Objects(index).Lights(light_index).IsOn()
+
+
+class ObiParticles(OutputData):
+    def get_data(self) -> ObiP.ObiParticles:
+        return ObiP.ObiParticles.GetRootAsObiParticles(self.bytes, 0)
+
+    def get_num_solvers(self) -> int:
+        return self.data.SolversLength()
+
+    def get_positions(self, index: int) -> np.array:
+        return self.data.Solvers(index).PositionsAsNumpy()
+
+    def get_velocities(self, index: int) -> np.array:
+        return self.data.Solvers(index).VelocitiesAsNumpy()
+
+    def get_num_objects(self) -> int:
+        return self.data.ActorsLength()
+
+    def get_object_id(self, index: int) -> int:
+        return self.data.Actors(index).Id()
+
+    def get_solver_id(self, index: int) -> int:
+        return self.data.Actors(index).SolverId()
+
+    def get_count(self, index: int) -> int:
+        return self.data.Actors(index).Count()
+
+    def get_solver_indices(self, index: int) -> np.array:
+        return self.data.Actors(index).SolverIndicesAsNumpy()
